==> ui-18.0.4.tgz: package/components/upload/UploadAction.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { DeleteOutlined, DownloadOutlined, EyeOutlined } from '@react-devui/icons';
import { getClassName, saveFile } from '@react-devui/utils';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DUpload.Action' });
function UploadAction(props, ref) {
    var _a, _b, _c, _d, _e, _f, _g;
    const _h = useComponentConfig(COMPONENT_NAME, props), { children, dPreset, __file, __defaultActions, __onRemove } = _h, restProps = __rest(_h, ["children", "dPreset", "__file", "__defaultActions", "__onRemove"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [t] = useTranslation();
    const defaultAction = dPreset === 'preview' ? __defaultActions === null || __defaultActions === void 0 ? void 0 : __defaultActions.preview : dPreset === 'download' ? __defaultActions === null || __defaultActions === void 0 ? void 0 : __defaultActions.download : undefined;
    return dPreset === 'preview' ? (_jsx("a", Object.assign({ className: getClassName(`${dPrefix}upload__item-action`, `${dPrefix}upload__item-action--preview`, {
            'is-disabled': isUndefined(__file.url),
        }), target: (_a = restProps['target']) !== null && _a !== void 0 ? _a : '_blank', href: __file.url, title: (_b = restProps.title) !== null && _b !== void 0 ? _b : t('Upload', 'Preview file'), onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            if (!isUndefined(defaultAction)) {
                e.preventDefault();
                defaultAction(__file);
            }
        } }, { children: children !== null && children !== void 0 ? children : _jsx(EyeOutlined, {}) }))) : dPreset === 'download' ? (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__item-action`), type: (_c = restProps['type']) !== null && _c !== void 0 ? _c : 'button', disabled: isUndefined(__file.url), onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            if (!isUndefined(defaultAction)) {
                defaultAction(__file);
            }
            else {
                saveFile(__file.url, __file.name);
            }
        }, title: (_d = restProps.title) !== null && _d !== void 0 ? _d : t('Upload', 'Download file') }, { children: children !== null && children !== void 0 ? children : _jsx(DownloadOutlined, {}) }))) : dPreset === 'remove' ? (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__item-action`), type: (_e = restProps['type']) !== null && _e !== void 0 ? _e : 'button', onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            __onRemove === null || __onRemove === void 0 ? void 0 : __onRemove();
        }, title: (_f = restProps.title) !== null && _f !== void 0 ? _f : t('Upload', 'Remove file') }, { children: children !== null && children !== void 0 ? children : _jsx(DeleteOutlined, {}) }))) : (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__item-action`), type: (_g = restProps['type']) !== null && _g !== void 0 ? _g : 'button', onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
        } }, { children: children })));
}
export const DUploadAction = React.forwardRef(UploadAction);

==> ui-18.1.4.tgz: package/components/upload/UploadAction.js <==
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx } from "react/jsx-runtime";
import { isUndefined } from 'lodash';
import React from 'react';
import { DeleteOutlined, DownloadOutlined, EyeOutlined } from '@react-devui/icons';
import { getClassName, saveFile } from '@react-devui/utils';
import { registerComponentMate } from '../../utils';
import { useComponentConfig, usePrefixConfig, useTranslation } from '../root';
const { COMPONENT_NAME } = registerComponentMate({ COMPONENT_NAME: 'DUpload.Action' });
function UploadAction(props, ref) {
    var _a, _b, _c, _d, _e, _f, _g;
    const _h = useComponentConfig(COMPONENT_NAME, props), { children, dPreset, __file, __defaultActions, __onRemove } = _h, restProps = __rest(_h, ["children", "dPreset", "__file", "__defaultActions", "__onRemove"]);
    //#region Context
    const dPrefix = usePrefixConfig();
    //#endregion
    const [t] = useTranslation();
    const defaultAction = dPreset === 'preview' ? __defaultActions === null || __defaultActions === void 0 ? void 0 : __defaultActions.preview : dPreset === 'download' ? __defaultActions === null || __defaultActions === void 0 ? void 0 : __defaultActions.download : undefined;
    return dPreset === 'preview' ? (_jsx("a", Object.assign({ className: getClassName(restProps.className, `${dPrefix}upload__action`, `${dPrefix}upload__action--preview`, {
            'is-disabled': isUndefined(__file.url),
        }), target: (_a = restProps['target']) !== null && _a !== void 0 ? _a : '_blank', href: __file.url, title: (_b = restProps.title) !== null && _b !== void 0 ? _b : t('Upload', 'Preview file'), onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            if (!isUndefined(defaultAction)) {
                e.preventDefault();
                defaultAction(__file);
            }
        } }, { children: children !== null && children !== void 0 ? children : _jsx(EyeOutlined, {}) }))) : dPreset === 'download' ? (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__action`), type: (_c = restProps['type']) !== null && _c !== void 0 ? _c : 'button', disabled: isUndefined(__file.url), onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            if (!isUndefined(defaultAction)) {
                defaultAction(__file);
            }
            else {
                saveFile(__file.url, __file.name);
            }
        }, title: (_d = restProps.title) !== null && _d !== void 0 ? _d : t('Upload', 'Download file') }, { children: children !== null && children !== void 0 ? children : _jsx(DownloadOutlined, {}) }))) : dPreset === 'remove' ? (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__action`), type: (_e = restProps['type']) !== null && _e !== void 0 ? _e : 'button', onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
            __onRemove === null || __onRemove === void 0 ? void 0 : __onRemove();
        }, title: (_f = restProps.title) !== null && _f !== void 0 ? _f : t('Upload', 'Remove file') }, { children: children !== null && children !== void 0 ? children : _jsx(DeleteOutlined, {}) }))) : (_jsx("button", Object.assign({}, restProps, { ref: ref, className: getClassName(restProps.className, `${dPrefix}upload__action`), type: (_g = restProps['type']) !== null && _g !== void 0 ? _g : 'button', onClick: (e) => {
            var _a;
            (_a = restProps.onClick) === null || _a === void 0 ? void 0 : _a.call(restProps, e);
            e.stopPropagation();
        } }, { children: children })));
}
export const DUploadAction = React.forwardRef(UploadAction);
